Changelog
=========

0.1.4
-----
#. Remove redundant photosize.
#. Wrapping div around image and content on detail view.

0.1.3
-----
# Corrected MANIFEST.in to include missing setup.py rst files.

0.1.2
-----
#. django-ckeditor now has minimum version 3.6.2.1. It now uses Pillow instead of PIL.

0.1.1
-----
#. Use slug for lookups in tastypie API.

0.1
---
#. django-tastypie support added.

0.0.6
-----
#. Unomena contributions.
#. Only show content type title if view modifiers are available.
#. Add Afrikaans and French translation.
